@@ -324,7 +324,7 @@ brasero_drive_selection_show_type (BraseroDriveSelection *selector,
 
 			drive = item->data;
 
-			drive_name =  brasero_drive_get_display_name (drive);
+			drive_name = brasero_drive_get_display_name (drive);
 
 			if (!brasero_drive_is_fake (drive)) {
 				GDrive *gdrive;
@@ -371,9 +371,9 @@ brasero_drive_selection_drive_added_cb (BraseroMediumMonitor *monitor,
 					BraseroDriveSelection *self)
 {
 	BraseroDriveSelectionPrivate *priv;
+	gchar *drive_name = NULL;
 	gboolean add = FALSE;
 	GtkTreeModel *model;
-	gchar *drive_name;
 	GIcon *drive_icon;
 	GtkTreeIter iter;
 
@@ -664,7 +664,15 @@ brasero_drive_selection_class_init (BraseroDriveSelectionClass *klass)
 			  1,
 			  BRASERO_TYPE_DRIVE);
 }
-  
+
+/**
+ * brasero_drive_selection_new:
+ *
+ * Creates a new #BraseroDriveSelection object
+ *
+ * Return value: a #GtkWidget. Unref when it is not needed anymore.
+ **/
+
 GtkWidget *
 brasero_drive_selection_new (void)
 {
