@@ -45,7 +45,6 @@
 
 #include <gconf/gconf-client.h>
 
-#include "burn-cdrdao-common.h"
 #include "brasero-error.h"
 #include "brasero-plugin-registration.h"
 #include "burn-job.h"
@@ -55,6 +54,7 @@
 #include "brasero-drive.h"
 #include "brasero-medium.h"
 
+#define CDRDAO_DESCRIPTION		N_("cdrdao burning suite")
 
 #define BRASERO_TYPE_CDRDAO         (brasero_cdrdao_get_type ())
 #define BRASERO_CDRDAO(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), BRASERO_TYPE_CDRDAO, BraseroCdrdao))
@@ -66,7 +66,8 @@
 BRASERO_PLUGIN_BOILERPLATE (BraseroCdrdao, brasero_cdrdao, BRASERO_TYPE_PROCESS, BraseroProcess);
 
 struct _BraseroCdrdaoPrivate {
-  	guint use_raw:1;
+ 	gchar *tmp_toc_path;
+	guint use_raw:1;
 };
 typedef struct _BraseroCdrdaoPrivate BraseroCdrdaoPrivate;
 #define BRASERO_CDRDAO_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_CDRDAO, BraseroCdrdaoPrivate)) 
@@ -196,8 +197,7 @@ brasero_cdrdao_read_stderr_record (BraseroCdrdao *cdrdao, const gchar *line)
 		if (!cuepath)
 			return FALSE;
 
-		if (!strstr (line, cuepath)
-		&&  !strstr (line, "ERROR: Could not find input file")) {
+		if (!strstr (line, "ERROR: Could not find input file")) {
 			g_free (cuepath);
 			return FALSE;
 		}
@@ -214,7 +214,7 @@ brasero_cdrdao_read_stderr_record (BraseroCdrdao *cdrdao, const gchar *line)
 		g_free (name);
 	}
 
-	return TRUE;
+	return FALSE;
 }
 
 static BraseroBurnResult
@@ -243,12 +243,6 @@ brasero_cdrdao_read_stderr (BraseroProcess *process, const gchar *line)
 						BRASERO_BURN_ERROR_DRIVE_BUSY,
 						_("The drive is busy")));
 	}
-	else if (strstr (line, "Illegal command")) {
-		brasero_job_error (BRASERO_JOB (cdrdao),
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_GENERAL,
-						_("Your version of cdrdao does not seem to be supported by libbrasero")));
-	}
 	else if (strstr (line, "Operation not permitted. Cannot send SCSI")) {
 		brasero_job_error (BRASERO_JOB (cdrdao),
 				   g_error_new (BRASERO_BURN_ERROR,
@@ -361,6 +355,8 @@ brasero_cdrdao_set_argv_record (BraseroCdrdao *cdrdao,
 		gchar *cuepath;
 		BraseroTrack *track;
 
+		g_ptr_array_add (argv, g_strdup ("write"));
+		
 		brasero_job_get_current_track (BRASERO_JOB (cdrdao), &track);
 
 		if (brasero_track_type_get_image_format (type) == BRASERO_IMAGE_FORMAT_CUE) {
@@ -370,9 +366,17 @@ brasero_cdrdao_set_argv_record (BraseroCdrdao *cdrdao,
 			parent = g_path_get_dirname (cuepath);
 			brasero_process_set_working_directory (BRASERO_PROCESS (cdrdao), parent);
 			g_free (parent);
+
+			/* This does not work as toc2cue will use BINARY even if
+			 * if endianness is big endian */
+			/* we need to check endianness */
+			/* if (brasero_track_image_need_byte_swap (BRASERO_TRACK_IMAGE (track)))
+				g_ptr_array_add (argv, g_strdup ("--swap")); */
 		}
-		else if (brasero_track_type_get_image_format (type) == BRASERO_IMAGE_FORMAT_CDRDAO)
+		else if (brasero_track_type_get_image_format (type) == BRASERO_IMAGE_FORMAT_CDRDAO) {
+			/* CDRDAO files are always BIG ENDIAN */
 			cuepath = brasero_track_image_get_toc_source (BRASERO_TRACK_IMAGE (track), FALSE);
+		}
 		else {
 			brasero_track_type_free (type);
 			BRASERO_JOB_NOT_SUPPORTED (cdrdao);
@@ -383,8 +387,6 @@ brasero_cdrdao_set_argv_record (BraseroCdrdao *cdrdao,
 			BRASERO_JOB_NOT_READY (cdrdao);
 		}
 
-		g_ptr_array_add (argv, g_strdup ("write"));
-
 		brasero_cdrdao_set_argv_device (cdrdao, argv);
 		brasero_cdrdao_set_argv_common (cdrdao, argv);
 		brasero_cdrdao_set_argv_common_rec (cdrdao, argv);
@@ -432,6 +434,56 @@ brasero_cdrdao_set_argv_blank (BraseroCdrdao *cdrdao,
 	return BRASERO_BURN_OK;
 }
 
+static BraseroBurnResult
+brasero_cdrdao_post (BraseroJob *job)
+{
+	BraseroCdrdaoPrivate *priv;
+
+	priv = BRASERO_CDRDAO_PRIVATE (job);
+	if (!priv->tmp_toc_path) {
+		brasero_job_finished_session (job);
+		return BRASERO_BURN_OK;
+	}
+
+	/* we have to run toc2cue now to convert the toc file into a cue file */
+	return BRASERO_BURN_RETRY;
+}
+
+static BraseroBurnResult
+brasero_cdrdao_start_toc2cue (BraseroCdrdao *cdrdao,
+			      GPtrArray *argv,
+			      GError **error)
+{
+	gchar *cue_output;
+	BraseroBurnResult result;
+	BraseroCdrdaoPrivate *priv;
+
+	priv = BRASERO_CDRDAO_PRIVATE (cdrdao);
+
+	g_ptr_array_add (argv, g_strdup ("toc2cue"));
+
+	g_ptr_array_add (argv, priv->tmp_toc_path);
+	priv->tmp_toc_path = NULL;
+
+	result = brasero_job_get_image_output (BRASERO_JOB (cdrdao),
+					       NULL,
+					       &cue_output);
+	if (result != BRASERO_BURN_OK)
+		return result;
+
+	g_ptr_array_add (argv, cue_output);
+
+	/* if there is a file toc2cue will fail */
+	g_remove (cue_output);
+
+	brasero_job_set_current_action (BRASERO_JOB (cdrdao),
+					BRASERO_BURN_ACTION_CREATING_IMAGE,
+					_("Converting toc file"),
+					TRUE);
+
+	return BRASERO_BURN_OK;
+}
+
 static BraseroBurnResult
 brasero_cdrdao_set_argv_image (BraseroCdrdao *cdrdao,
 			       GPtrArray *argv,
@@ -439,11 +491,16 @@ brasero_cdrdao_set_argv_image (BraseroCdrdao *cdrdao,
 {
 	gchar *image = NULL, *toc = NULL;
 	BraseroTrackType *output = NULL;
+	BraseroCdrdaoPrivate *priv;
 	BraseroBurnResult result;
 	BraseroJobAction action;
 	BraseroDrive *drive;
 	BraseroTrack *track;
 
+	priv = BRASERO_CDRDAO_PRIVATE (cdrdao);
+	if (priv->tmp_toc_path)
+		return brasero_cdrdao_start_toc2cue (cdrdao, argv, error);
+
 	g_ptr_array_add (argv, g_strdup ("cdrdao"));
 	g_ptr_array_add (argv, g_strdup ("read-cd"));
 	g_ptr_array_add (argv, g_strdup ("--device"));
@@ -473,7 +530,9 @@ brasero_cdrdao_set_argv_image (BraseroCdrdao *cdrdao,
 			return result;
 		}
 	}
-	else {
+	else if (brasero_track_type_get_image_format (output) == BRASERO_IMAGE_FORMAT_CUE) {
+		/* NOTE: we don't generate the .cue file right away; we'll call
+		 * toc2cue right after we finish */
 		result = brasero_job_get_image_output (BRASERO_JOB (cdrdao),
 						       &image,
 						       NULL);
@@ -481,15 +540,19 @@ brasero_cdrdao_set_argv_image (BraseroCdrdao *cdrdao,
 			brasero_track_type_free (output);
 			return result;
 		}
-	
+
 		result = brasero_job_get_tmp_file (BRASERO_JOB (cdrdao),
 						   NULL,
 						   &toc,
 						   error);
 		if (result != BRASERO_BURN_OK) {
+			g_free (image);
 			brasero_track_type_free (output);
 			return result;
 		}
+
+		/* save the temporary toc path to resuse it later. */
+		priv->tmp_toc_path = g_strdup (toc);
 	}
 
 	brasero_track_type_free (output);
@@ -580,7 +643,7 @@ brasero_cdrdao_class_init (BraseroCdrdaoClass *klass)
 
 	process_class->stderr_func = brasero_cdrdao_read_stderr;
 	process_class->set_argv = brasero_cdrdao_set_argv;
-	process_class->post = brasero_job_finished_session;
+	process_class->post = brasero_cdrdao_post;
 }
 
 static void
@@ -596,13 +659,20 @@ brasero_cdrdao_init (BraseroCdrdao *obj)
  	priv->use_raw = gconf_client_get_bool (client,
 					       GCONF_KEY_RAW_FLAG,
 					       NULL);
-
  	g_object_unref (client); 
 }
 
 static void
 brasero_cdrdao_finalize (GObject *object)
 {
+	BraseroCdrdaoPrivate *priv;
+
+	priv = BRASERO_CDRDAO_PRIVATE (object);
+	if (priv->tmp_toc_path) {
+		g_free (priv->tmp_toc_path);
+		priv->tmp_toc_path = NULL;
+	}
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -643,7 +713,11 @@ brasero_cdrdao_export_caps (BraseroPlugin *plugin)
 	/* an image can be created ... */
 	output = brasero_caps_image_new (BRASERO_PLUGIN_IO_ACCEPT_FILE,
 					 BRASERO_IMAGE_FORMAT_CDRDAO);
+	brasero_plugin_link_caps (plugin, output, input);
+	g_slist_free (output);
 
+	output = brasero_caps_image_new (BRASERO_PLUGIN_IO_ACCEPT_FILE,
+					 BRASERO_IMAGE_FORMAT_CUE);
 	brasero_plugin_link_caps (plugin, output, input);
 	g_slist_free (output);
 
@@ -704,4 +778,10 @@ brasero_plugin_check_config (BraseroPlugin *plugin)
 	                         "version",
 	                         "Cdrdao version %d.%d.%d - (C) Andreas Mueller <andreas@daneb.de>",
 	                         version);
+
+	brasero_plugin_test_app (plugin,
+	                         "toc2cue",
+	                         "-V",
+	                         "%d.%d.%d",
+	                         version);
 }
