@@ -1,20 +1,23 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
- * brasero
- * Copyright (C) Philippe Rouquier 2005-2008 <bonfire-app@wanadoo.fr>
+ * Brasero
+ * Copyright (C) Philippe Rouquier 2005-2009 <bonfire-app@wanadoo.fr>
  * 
- * brasero is free software: you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ *  Brasero is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  * 
- * brasero is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * brasero is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * 
- * You should have received a copy of the GNU General Public License along
- * with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with brasero.  If not, write to:
+ * 	The Free Software Foundation, Inc.,
+ * 	51 Franklin Street, Fifth Floor
+ * 	Boston, MA  02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -115,17 +118,17 @@ brasero_rename_delete_string (BraseroRename *self,
 {
 	BraseroRenamePrivate *priv;
 	const gchar *text;
-	gchar *occurence;
+	gchar *occurrence;
 
 	priv = BRASERO_RENAME_PRIVATE (self);
 
 	text = gtk_entry_get_text (GTK_ENTRY (priv->delete_entry));
-	occurence = g_strstr_len (name, -1, text);
+	occurrence = g_strstr_len (name, -1, text);
 
-	if (!occurence)
+	if (!occurrence)
 		return NULL;
 
-	return g_strdup_printf ("%.*s%s", occurence - name, name, occurence + strlen (text));
+	return g_strdup_printf ("%.*s%s", (int) (occurrence - name), name, occurrence + strlen (text));
 }
 
 static gchar *
@@ -135,18 +138,18 @@ brasero_rename_substitute_string (BraseroRename *self,
 	BraseroRenamePrivate *priv;
 	const gchar *joker;
 	const gchar *text;
-	gchar *occurence;
+	gchar *occurrence;
 
 	priv = BRASERO_RENAME_PRIVATE (self);
 
 	text = gtk_entry_get_text (GTK_ENTRY (priv->substitute_entry));
-	occurence = g_strstr_len (name, -1, text);
+	occurrence = g_strstr_len (name, -1, text);
 
-	if (!occurence)
+	if (!occurrence)
 		return NULL;
 
 	joker = gtk_entry_get_text (GTK_ENTRY (priv->joker_entry));
-	return g_strdup_printf ("%.*s%s%s", occurence - name, name, joker, occurence + strlen (text));
+	return g_strdup_printf ("%.*s%s%s", (int) (occurrence - name), name, joker, occurrence + strlen (text));
 }
 
 static gchar *
@@ -164,6 +167,30 @@ brasero_rename_number_string (BraseroRename *self,
 	return g_strdup_printf ("%s%i%s", left, priv->number ++, right);
 }
 
+static gchar *
+brasero_rename_sequence_string (BraseroRename *self,
+                                const gchar *name,
+                                guint item_num,
+                                guint nb_items)
+{
+	BraseroRenamePrivate *priv;
+	gboolean is_at_end;
+
+	priv = BRASERO_RENAME_PRIVATE (self);
+
+	is_at_end = gtk_combo_box_get_active (GTK_COMBO_BOX (priv->insert_combo)) != 0;
+
+	if (nb_items < 10){
+		return g_strdup_printf ("%i%s", item_num, name);
+	} else if (nb_items < 100){
+		return g_strdup_printf ("%02i%s", item_num, name);       
+	} else if (nb_items < 1000){
+		return g_strdup_printf ("%03i%s", item_num, name);       
+	} else {
+		return g_strdup_printf ("%04i%s", item_num, name); 
+	}
+}
+
 gboolean
 brasero_rename_do (BraseroRename *self,
 		   GtkTreeSelection *selection,
@@ -173,16 +200,24 @@ brasero_rename_do (BraseroRename *self,
 	BraseroRenamePrivate *priv;
 	GtkTreeModel *model;
 	GList *selected;
+	guint item_num;
+	guint nb_items;
 	GList *item;
 	guint mode;
 
 	priv = BRASERO_RENAME_PRIVATE (self);
 	mode = gtk_combo_box_get_active (GTK_COMBO_BOX (priv->combo));
-	if (!mode)
+
+	mode -= priv->show_default;
+	if (mode < 0)
 		return TRUE;
 
 	selected = gtk_tree_selection_get_selected_rows (selection, &model);
-	for (item = selected; item; item = item->next) {
+
+	nb_items = g_list_length (selected);
+	item_num = 0;
+
+	for (item = selected; item; item = item->next, item_num ++) {
 		GtkTreePath *treepath;
 		GtkTreeIter iter;
 		gboolean result;
@@ -198,18 +233,21 @@ brasero_rename_do (BraseroRename *self,
 
 redo:
 		switch (mode) {
-		case 1:
+		case 0:
 			new_name = brasero_rename_insert_string (self, name);
 			break;
-		case 2:
+		case 1:
 			new_name = brasero_rename_delete_string (self, name);
 			break;
-		case 3:
+		case 2:
 			new_name = brasero_rename_substitute_string (self, name);
 			break;
-		case 4:
+		case 3:
 			new_name = brasero_rename_number_string (self, name);
 			break;
+		case 4:
+			new_name = brasero_rename_sequence_string (self, name, item_num, nb_items);
+			break;
 		default:
 			new_name = NULL;
 			break;
@@ -244,7 +282,9 @@ brasero_rename_type_changed (GtkComboBox *combo,
 	BraseroRenamePrivate *priv;
 
 	priv = BRASERO_RENAME_PRIVATE (self);
-	if (gtk_combo_box_get_active (combo) == -1) {
+
+	if (gtk_combo_box_get_active (combo) - priv->show_default < 0
+	||  gtk_combo_box_get_active (combo) - priv->show_default == 4) {
 		gtk_widget_hide (priv->notebook);
 		return;
 	}
@@ -276,11 +316,12 @@ brasero_rename_init (BraseroRename *object)
 	gtk_box_pack_start (GTK_BOX (object), priv->combo, FALSE, FALSE, 0);
 
 	priv->show_default = 1;
-	gtk_combo_box_append_text (GTK_COMBO_BOX (priv->combo), _("<Keep current values>"));
+	gtk_combo_box_prepend_text (GTK_COMBO_BOX (priv->combo), _("<Keep current values>"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (priv->combo), _("Insert text"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (priv->combo), _("Delete text"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (priv->combo), _("Substitute text"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (priv->combo), _("Number files according to a pattern"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (priv->combo), _("Insert number sequence at beginning"));
 
 	g_signal_connect (priv->combo,
 			  "changed",
@@ -309,7 +350,7 @@ brasero_rename_init (BraseroRename *object)
 
 	/* Translators: This finishes previous action "Insert". It goes like
 	 * this: "Insert" [Entry] "at the beginning". */
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("at the begining"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("at the beginning"));
 
 	/* Translators: This finishes previous action "Insert". It goes like
 	 * this: "Insert" [Entry] "at the end". */
@@ -324,7 +365,7 @@ brasero_rename_init (BraseroRename *object)
 	gtk_widget_show (hbox);
 	gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook), hbox, NULL);
 
-	label = gtk_label_new (_("Delete every occurence of"));
+	label = gtk_label_new (_("Delete every occurrence of"));
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
